@Echo Off

rem ---------------------------------------------------------------------------
rem Fractal Deployment Framework
rem Copyright (C) 2007 INRIA - ADAM Team
rem Contact: fdf-users@lists.gforge.inria.fr
rem
rem This library is free software; you can redistribute it and/or
rem modify it under the terms of the GNU Lesser General Public
rem License as published by the Free Software Foundation; either
rem version 2.1 of the License, or any later version.
rem
rem This library is distributed in the hope that it will be useful,
rem but WITHOUT ANY WARRANTY; without even the implied warranty of
rem MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
rem Lesser General Public License for more details.
rem
rem You should have received a copy of the GNU Lesser General Public
rem License along with this library; if not, write to the Free Software
rem Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
rem USA
rem
rem Initial developer(s): Philippe Merle.
rem Contributor(s): Nicolas Dolet.
rem ---------------------------------------------------------------------------

rem -----------------------------------------------------------------------
rem Check PETALS_HOME
rem -----------------------------------------------------------------------

if "%JAVA_HOME%" == "" (
  echo The JAVA_HOME variable is not set. Please initialise it in your environment.
  goto :EOF
) else (
  set JAVA="%JAVA_HOME%\bin\java"
)

rem ---------------------------------------------------------------------------
rem Check FDF_LIB
rem ---------------------------------------------------------------------------

if "%FDF_HOME%" == "" (
  if exist ..\lib\ow-fdf-2.0.0.jar (
    set FDF_HOME=%~dp0..
    set FDF_LIB=%FDF_HOME%\lib
  ) else (
    echo The FDF_HOME variable is not set. Please initialise it in your environment.
    goto :EOF
  )
)

rem -----------------------------------------------------------------------
rem Set Java and Fractal options
rem -----------------------------------------------------------------------

set JAVA_OPTS=-Djava.security.policy=%FDF_HOME%\conf\java.policy
set JAVA_OPTS=%JAVA_OPTS% -Dfractal.provider=org.objectweb.fractal.julia.Julia
set JAVA_OPTS=%JAVA_OPTS% -Djulia.config=%FDF_HOME%\conf\julia-fdf.cfg
set JAVA_OPTS=%JAVA_OPTS% -Djulia.loader=org.objectweb.fractal.julia.loader.DynamicLoader
set JAVA_OPTS=%JAVA_OPTS% -Djulia.loader.use-context-class-loader=true

set CLASS_TO_RUN=org.objectweb.fdf.adl.Launcher

rem -----------------------------------------------------------------------
rem Set FDF Explorer configuration
rem -----------------------------------------------------------------------

set EXPLORER_PARAMS=-fractal org.objectweb.fdf.explorer.Explorer(FDF_Explorer) r

rem -----------------------------------------------------------------------
rem Set the CLASSPATH
rem -----------------------------------------------------------------------

set CLASSPATH=%FDF_HOME%\examples
set CLASSPATH=%CLASSPATH%;%FDF_HOME%\conf
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\asm-2.0.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\fractal-api-2.0.2.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\dtdparser-1.21.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\fractal-adl-fdf.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\task-framework-2.1.7.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\apollon-runtime-1.0.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\bsh-2.0b1.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\explorer-1.0.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\explorer-reflector-plugin-1.0.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\jgraph-5.8.3.1.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\commandline-1.0.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\ow-misc-1.0.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\objectweb-util-trace-1.0.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\fractal-explorer-1.1.2.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\julia-asm-2.0.3.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\julia-runtime-2.0.3.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\julia-mixins-2.0.3.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\monolog-2.1.1.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\log4j-1.2.13.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\commons-net-1.4.1.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\jsch-0.1.29.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\jtelnet.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\xercesImpl-2.3.0.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\mx4j-3.0.1.jar
set CLASSPATH=%CLASSPATH%;%FDF_LIB%\ow-fdf-2.0.0.jar


if [%1]==[run] goto console_mode

if [%1]==[explorer] goto explorer_mode

goto usage

:console_mode
set DESCRIPTION=%2
set PROCEDURE=%3

if [%PROCEDURE%]==[install] goto run
if [%PROCEDURE%]==[start] goto run
if [%PROCEDURE%]==[stop] goto run
if [%PROCEDURE%]==[uninstall] goto run
goto procedures

:run
set LAUNCHER=-fractal org.objectweb.fdf.components.fdf.lib.runnable.Launcher(%DESCRIPTION%,%PROCEDURE%,,,,) r

%JAVA% -classpath %CLASSPATH% %JAVA_OPTS% %CLASS_TO_RUN% %LAUNCHER%
goto EOF

:procedures
echo "Authorized procedures are: install | start | stop | uninstall"
goto :EOF

:explorer_mode
%JAVA% -classpath %CLASSPATH% %JAVA_OPTS% %CLASS_TO_RUN% %EXPLORER_PARAMS%

goto EOF

:usage
echo "Usage: fdf run|explorer"
echo "   Explorer mode: > fdf explorer"
echo "                 (will display the GUI)"
echo "   Console mode:  > fdf run description_file install|start|stop|uninstall"
echo "                 (will perform the deployment in text mode)"

:EOF
