#!/bin/sh
# ---------------------------------------------------------------------------
# Fractal Deployment Framework
# Copyright (C) 2007 INRIA - ADAM Team
# Contact: fdf-users@lists.gforge.inria.fr
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
# USA
#
# Initial developer(s): Nicolas Dolet
#
# Contributor(s): 
#
# ---------------------------------------------------------------------------
# $Id: fdf.sh
# ---------------------------------------------------------------------------

# -----------------------------------------------------------------------
# Check PETALS_HOME
# -----------------------------------------------------------------------

RepScript=`dirname $0`
RepCourant=`pwd`

# -----------------------------------------------------------------------
# Check JAVA_HOME
# -----------------------------------------------------------------------

if [ -z $JAVA_HOME ]
then
  echo "The JAVA_HOME variable is not set. Please initialise it in your environment."
  exit 1
else
  JAVA=$JAVA_HOME/bin/java
fi

# -----------------------------------------------------------------------
# Set FDF_LIB
# -----------------------------------------------------------------------

if [ -z $FDF_HOME ]
then
  FDF_HOME=$RepCourant/$RepScript/../
fi

if [ -z "${FDF_LIB}" ]
then
  FDF_LIB=${FDF_HOME}/lib
fi

# -----------------------------------------------------------------------
# Set Fractal options
# -----------------------------------------------------------------------

JAVA_OPTS="\
-Djava.security.policy=${FDF_HOME}/conf/java.policy \
-Dfractal.provider=org.objectweb.fractal.julia.Julia \
-Djulia.config=${FDF_HOME}/conf/julia-fdf.cfg \
-Djulia.loader=org.objectweb.fractal.julia.loader.DynamicLoader \
-Djulia.loader.use-context-class-loader=true"

CLASS_TO_RUN=org.objectweb.fdf.adl.Launcher

# -----------------------------------------------------------------------
# Set FDF Explorer configuration
# -----------------------------------------------------------------------

EXPLORER_PARAMS="-fractal org.objectweb.fdf.explorer.Explorer(FDF-Explorer) r"

# -----------------------------------------------------------------------
# Set the CLASSPATH
# -----------------------------------------------------------------------

CLASSPATH=\
${FDF_HOME}/examples:\
${FDF_HOME}/conf:\
${FDF_LIB}/asm-2.0.jar:\
${FDF_LIB}/fractal-api-2.0.2.jar:\
${FDF_LIB}/dtdparser-1.21.jar:\
${FDF_LIB}/fractal-adl-fdf.jar:\
${FDF_LIB}/task-framework-2.1.7.jar:\
${FDF_LIB}/apollon-runtime-1.0.jar:\
${FDF_LIB}/bsh-2.0b1.jar:\
${FDF_LIB}/explorer-1.0.jar:\
${FDF_LIB}/explorer-reflector-plugin-1.0.jar:\
${FDF_LIB}/jgraph-5.8.3.1.jar:\
${FDF_LIB}/commandline-1.0.jar:\
${FDF_LIB}/ow-misc-1.0.jar:\
${FDF_LIB}/objectweb-util-trace-1.0.jar:\
${FDF_LIB}/fractal-explorer-1.1.2.jar:\
${FDF_LIB}/julia-asm-2.1.3.jar:\
${FDF_LIB}/julia-runtime-2.1.3.jar:\
${FDF_LIB}/julia-mixins-2.1.3.jar:\
${FDF_LIB}/monolog-2.1.1.jar:\
${FDF_LIB}/log4j-1.2.13.jar:\
${FDF_LIB}/commons-net-1.4.1.jar:\
${FDF_LIB}/jsch-0.1.29.jar:\
${FDF_LIB}/jtelnet.jar:\
${FDF_LIB}/xercesImpl-2.3.0.jar:\
${FDF_LIB}/mx4j-3.0.1.jar:\
${FDF_LIB}/ow-fdf-2.0.0.jar

export CLASSPATH

# -----------------------------------------------------------------------
# Parse command line arguments
# -----------------------------------------------------------------------

case "$1" in
  run)
    MODE=run
    DESCRIPTION=$2
    PROCEDURE=$3;;
  explorer)
    MODE=explorer
    ;;
  *)
    echo "Usage: fdf run|explorer [options]"
    echo "   Explorer mode: > fdf explorer"
    echo "                 (will display the GUI)"
    echo "   Console mode:  > fdf run description_file install|start|stop|uninstall"
    echo "                 (will perform the deployment in text mode)"
    exit 1
    ;;
esac

# -----------------------------------------------------------------------
# Run FDF
# -----------------------------------------------------------------------

case "$MODE" in
  run)
    if ! [ "$PROCEDURE" = "install" -o "$PROCEDURE" = "start" -o "$PROCEDURE" = "stop" -o "$PROCEDURE" = "uninstall" ]
    then
      echo "Authorized procedures are: install | start | stop | uninstall"
      exit 1
    fi
    LAUNCHER="-fractal org.objectweb.fdf.components.fdf.lib.runnable.Launcher($DESCRIPTION,$PROCEDURE,,,,) r"
    exec $JAVA -classpath $CLASSPATH $JAVA_OPTS $CLASS_TO_RUN $LAUNCHER
    ;;
  explorer)
    exec $JAVA $JAVA_OPTS -classpath $CLASSPATH $CLASS_TO_RUN $EXPLORER_PARAMS
    ;;
esac
