#!/bin/sh

RepScript=`dirname $0`
RepCourant=`pwd`

usage()
{
	echo "The startup.sh script is used to start Petals."
	echo "usage : startup.sh [-h|-?] [-D|C] [-E] [-P <profilerId>]"
	echo "     -h|? : prints the help message"
	echo "     -D : Petals is starting in daemon mode"
	echo "     -C : Petals is starting with command line"
	echo "     -E : Petals is starting with command line and the Fractal Explorer"
	exit 0;
}

# arguments analysis
DaemonMode=false
CommandLine=false
while getopts :hv:Dv:Cv:Ev options
do
        case ${options} in
                h)
                        usage
                        ;;
                C)
                        CommandLine=true
                        CLOption="-console"
                        ;;
                E)
                        CommandLine=true
                        CLOption="-explore"
                        ;;
                D)
                        DaemonMode=true
                        ;;
                ?)
			usage
                        ;;
        esac
done


if [ $CommandLine != false -a $DaemonMode != false ]
then
        echo "Petals can be started in daemon mode or with command line, but not the two at the same time."
        echo "Use -D or -C!"
        exit 1
fi


echo "Setting Petals environment"

######################################
#   ENV VARIABLES
######################################


if [ -z $JAVA_HOME ]
then
	echo "The JAVA_HOME variable is not set. Please initialise it in your environment."
	exit 1
fi

if [ -z $PETALS_HOME ]
then
	export PETALS_HOME=$RepCourant/$RepScript/../
fi

if [ ! -f $PETALS_HOME/conf/server.properties ]
then
	echo "The PETALS_HOME environment variable cannot be set correctly. Please set it in your environment with the correct value."
	exit 2
fi


if [ ! -d $PETALS_HOME/logs ]
then
        mkdir $PETALS_HOME/logs
fi

PATH=$JAVA_HOME/bin/:$PATH
LOG_FILE=$PETALS_HOME/logs/petals-out.log

export PATH

######################################

cd $PETALS_HOME/bin

if [ $DaemonMode != false ]
then
        echo "Petals starting in deamon mode..."
        nohup java -Xmx1024m -server -jar server.jar $1 $2 1>$LOG_FILE 2>>$LOG_FILE  &
        Return=$?
else
        java -Xmx1024m -server -jar server.jar $CLOption $1 $2
        Return=$?
fi

cd $RepCourant

if [ $Return != 0 ]
then
	exit 1
else
	exit 0
fi
